@@ -84,11 +84,11 @@ class FootprintFileReader(oasyswidget.OWWidget):
     def __init__(self):
         super().__init__()
 
-        self.setFixedWidth(590)
-        self.setFixedHeight(150)
+        self.setFixedWidth(585)
+        self.setFixedHeight(155)
 
         left_box_1 = oasysgui.widgetBox(self.controlArea, "Footprint Settings", addSpace=True, orientation="vertical",
-                                         width=570, height=120)
+                                         width=570, height=130)
 
         self.le_beam_file_name = oasysgui.lineEdit(left_box_1, self, "beam_file_name", "Shadow File Name", labelWidth=120, valueType=str, orientation="horizontal")
         self.le_beam_file_name.setReadOnly(True)
@@ -103,84 +103,92 @@ class FootprintFileReader(oasyswidget.OWWidget):
         gui.comboBox(left_box_1, self, "kind_of_power", label="Kind Of Power",
                      items=["Incident", "Absorbed", "Transmitted"], labelWidth=260, sendSelectedValue=False, orientation="horizontal")
 
+        gui.separator(left_box_1)
+
+        gui.button(left_box_1, self, "Send Footprint", callback=self.calculate_footprint(), height=25)
 
         gui.rubber(self.controlArea)
 
     def setBeam(self, beam):
-        if ShadowCongruence.checkEmptyBeam(beam[0]) and ShadowCongruence.checkGoodBeam(beam[0]):
-            self.input_beam     = beam[0]
-            self.footprint_beam = beam[1]
+        if not beam is None:
+            if ShadowCongruence.checkEmptyBeam(beam[0]) and ShadowCongruence.checkGoodBeam(beam[0]):
+                self.input_beam     = beam[0]
+                self.footprint_beam = beam[1]
 
-            self.calculate_footprint()
+                self.calculate_footprint()
+        else:
+            self.input_beam = None
+            self.footprint_beam = None
 
     def calculate_footprint(self):
         self.setStatusMessage("")
 
         try:
-            beam_out = self.footprint_beam.duplicate()
-            beam_out._oe_number = self.input_beam._oe_number
+            if not self.input_beam is None and not self.footprint_beam is None:
+                beam_out = self.footprint_beam.duplicate()
+                beam_out._oe_number = self.input_beam._oe_number
 
-            for history_item in self.input_beam.history:
-                beam_out.history.append(history_item) # Source
+                for history_item in self.input_beam.history:
+                    beam_out.history.append(history_item) # Source
 
-            is_scanning = self.input_beam.scanned_variable_data and self.input_beam.scanned_variable_data.has_additional_parameter("total_power")
+                is_scanning = self.input_beam.scanned_variable_data and self.input_beam.scanned_variable_data.has_additional_parameter("total_power")
 
-            additional_parameters = {}
+                additional_parameters = {}
 
-            if is_scanning:
-                total_power = self.input_beam.scanned_variable_data.get_additional_parameter("total_power")
+                if is_scanning:
+                    total_power = self.input_beam.scanned_variable_data.get_additional_parameter("total_power")
 
-                additional_parameters["total_power"]        = total_power
-                additional_parameters["photon_energy_step"] = self.input_beam.scanned_variable_data.get_additional_parameter("photon_energy_step")
+                    additional_parameters["total_power"]        = total_power
+                    additional_parameters["photon_energy_step"] = self.input_beam.scanned_variable_data.get_additional_parameter("photon_energy_step")
 
-            additional_parameters["is_footprint"] = True
+                additional_parameters["is_footprint"] = True
 
-            incident_beam = self.input_beam.getOEHistory(self.input_beam._oe_number)._input_beam
+                incident_beam = self.input_beam.getOEHistory(self.input_beam._oe_number)._input_beam
 
-            if is_scanning:
-                n_rays = len(beam_out._beam.rays[:, 0]) # lost and good!
+                if is_scanning:
+                    n_rays = len(beam_out._beam.rays[:, 0]) # lost and good!
 
-                ticket = incident_beam._beam.histo2(1, 3, nbins=100, xrange=None, yrange=None, nolost=1, ref=23)
-                ticket['histogram'] *= (total_power/n_rays) # power
+                    ticket = incident_beam._beam.histo2(1, 3, nbins=100, xrange=None, yrange=None, nolost=1, ref=23)
+                    ticket['histogram'] *= (total_power/n_rays) # power
 
-                additional_parameters["incident_power"] = ticket['histogram'].sum()
+                    additional_parameters["incident_power"] = ticket['histogram'].sum()
 
-            if self.kind_of_power == 0: # incident
-                beam_out._beam.rays[:, 6]  = incident_beam._beam.rays[:, 6]
-                beam_out._beam.rays[:, 7]  = incident_beam._beam.rays[:, 7]
-                beam_out._beam.rays[:, 8]  = incident_beam._beam.rays[:, 8]
-                beam_out._beam.rays[:, 15] = incident_beam._beam.rays[:, 15]
-                beam_out._beam.rays[:, 16] = incident_beam._beam.rays[:, 16]
-                beam_out._beam.rays[:, 17] = incident_beam._beam.rays[:, 17]
-            elif self.kind_of_power == 1: # absorbed
-                # need a trick: put the whole intensity of one single component
+                if self.kind_of_power == 0: # incident
+                    beam_out._beam.rays[:, 6]  = incident_beam._beam.rays[:, 6]
+                    beam_out._beam.rays[:, 7]  = incident_beam._beam.rays[:, 7]
+                    beam_out._beam.rays[:, 8]  = incident_beam._beam.rays[:, 8]
+                    beam_out._beam.rays[:, 15] = incident_beam._beam.rays[:, 15]
+                    beam_out._beam.rays[:, 16] = incident_beam._beam.rays[:, 16]
+                    beam_out._beam.rays[:, 17] = incident_beam._beam.rays[:, 17]
+                elif self.kind_of_power == 1: # absorbed
+                    # need a trick: put the whole intensity of one single component
 
-                incident_intensity = incident_beam._beam.rays[:, 6]**2 + incident_beam._beam.rays[:, 7]**2 + incident_beam._beam.rays[:, 8]**2 +\
-                                     incident_beam._beam.rays[:, 15]**2 + incident_beam._beam.rays[:, 16]**2 + incident_beam._beam.rays[:, 17]**2
-                transmitted_intensity = beam_out._beam.rays[:, 6]**2 + beam_out._beam.rays[:, 7]**2 + beam_out._beam.rays[:, 8]**2 +\
-                                        beam_out._beam.rays[:, 15]**2 + beam_out._beam.rays[:, 16]**2 + beam_out._beam.rays[:, 17]**2
+                    incident_intensity = incident_beam._beam.rays[:, 6]**2 + incident_beam._beam.rays[:, 7]**2 + incident_beam._beam.rays[:, 8]**2 +\
+                                         incident_beam._beam.rays[:, 15]**2 + incident_beam._beam.rays[:, 16]**2 + incident_beam._beam.rays[:, 17]**2
+                    transmitted_intensity = beam_out._beam.rays[:, 6]**2 + beam_out._beam.rays[:, 7]**2 + beam_out._beam.rays[:, 8]**2 +\
+                                            beam_out._beam.rays[:, 15]**2 + beam_out._beam.rays[:, 16]**2 + beam_out._beam.rays[:, 17]**2
 
-                electric_field = numpy.sqrt(incident_intensity - transmitted_intensity)
-                electric_field[numpy.where(electric_field == numpy.nan)] = 0.0
+                    electric_field = numpy.sqrt(incident_intensity - transmitted_intensity)
+                    electric_field[numpy.where(electric_field == numpy.nan)] = 0.0
 
-                beam_out._beam.rays[:, 6]  = electric_field
-                beam_out._beam.rays[:, 7]  = 0.0
-                beam_out._beam.rays[:, 8]  = 0.0
-                beam_out._beam.rays[:, 15] = 0.0
-                beam_out._beam.rays[:, 16] = 0.0
-                beam_out._beam.rays[:, 17] = 0.0
+                    beam_out._beam.rays[:, 6]  = electric_field
+                    beam_out._beam.rays[:, 7]  = 0.0
+                    beam_out._beam.rays[:, 8]  = 0.0
+                    beam_out._beam.rays[:, 15] = 0.0
+                    beam_out._beam.rays[:, 16] = 0.0
+                    beam_out._beam.rays[:, 17] = 0.0
 
-            if is_scanning:
-                beam_out.setScanningData(ShadowBeam.ScanningData(self.input_beam.scanned_variable_data.get_scanned_variable_name(),
-                                                                 self.input_beam.scanned_variable_data.get_scanned_variable_value(),
-                                                                 self.input_beam.scanned_variable_data.get_scanned_variable_display_name(),
-                                                                 self.input_beam.scanned_variable_data.get_scanned_variable_um(),
-                                                                 additional_parameters))
-            else:
-                beam_out.setScanningData(scanned_variable_data=ShadowBeam.ScanningData(None, None, None, None,
-                                                                                       additional_parameters=additional_parameters))
+                if is_scanning:
+                    beam_out.setScanningData(ShadowBeam.ScanningData(self.input_beam.scanned_variable_data.get_scanned_variable_name(),
+                                                                     self.input_beam.scanned_variable_data.get_scanned_variable_value(),
+                                                                     self.input_beam.scanned_variable_data.get_scanned_variable_display_name(),
+                                                                     self.input_beam.scanned_variable_data.get_scanned_variable_um(),
+                                                                     additional_parameters))
+                else:
+                    beam_out.setScanningData(scanned_variable_data=ShadowBeam.ScanningData(None, None, None, None,
+                                                                                           additional_parameters=additional_parameters))
 
-            self.send("Beam", beam_out)
+                self.send("Beam", beam_out)
         except Exception as exception:
             QtWidgets.QMessageBox.critical(self, "Error",
                                        str(exception), QtWidgets.QMessageBox.Ok)
